@@ -5,6 +5,13 @@
 #include <QDir>
 #include <QApplication>
 #include <QClipboard>
+#include <QtSql/QSqlDatabase>
+#include <QtSql/QSqlQuery>
+#include <QtSql/QSqlRecord>
+#include <QVariant>
+#include <QString>
+#include <QMap>
+#include <QTranslator>
 
 #ifdef Q_WS_MAEMO_5
 #include <QtDBus/QDBusConnection>
@@ -32,6 +39,34 @@ void Controller::toggleState() {
     }
 }
 
+void Controller::setLanguage() {
+    QMap<QString, QString> langs;
+    langs["German"] = "de";
+
+    QSqlDatabase db;
+    db = QSqlDatabase::addDatabase("QSQLITE");
+    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
+    db.open();
+
+    QSqlQuery query("select value from settings where setting = 'language'");
+    QSqlRecord record = query.record();
+    QString language;
+
+    if (record.count() > 0) {
+        while (query.next()) {
+            language = query.value(0).toString();
+        }
+//        qDebug() << language;
+        QString langCode = langs.value(language, "en");
+        if (langCode != "en") {
+            QTranslator translator;
+            if (translator.load("qml_" + langCode, "/opt/usr/share/qmltube/qml/qmltube/i18n")) {
+                QCoreApplication::installTranslator(&translator);
+            }
+        }
+    }
+}
+
 void Controller::setOrientation(const QString &orient) {
     if (orient == "Automatic") {
         m_view->setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
@@ -67,7 +102,7 @@ bool Controller::kmPlayerInstalled() {
 
 bool Controller::xTubeInstalled() {
     bool isInstalled = false;
-    if (QFile::exists("/opt/usr/share/qmltube/qml/qmltube/xtube.js")) {
+    if (QFile::exists("/opt/usr/share/qmltube/qml/qmltube/scripts/xtube.js")) {
         isInstalled = true;
     }
     return isInstalled;
@@ -86,14 +121,14 @@ void Controller::playVideo(const QString &url) {
 void Controller::deleteVideo(const QString &path) {
     if (QFile::exists(path)) {
         if (QFile::remove(path)) {
-            emit alert("Video deleted from device");
+            emit alert(tr("Video deleted from device"));
         }
         else {
-            emit alert("Unable to delete video");
+            emit alert(tr("Unable to delete video"));
         }
     }
     else {
-        emit alert("Video not found");
+        emit alert(tr("Video not found"));
     }
 }
 
@@ -148,5 +183,5 @@ void Controller::conversionFinished(int exitCode, QProcess::ExitStatus exitStatu
 
 void Controller::copyToClipboard(const QString &url) {
     QApplication::clipboard()->setText(url);
-    emit alert("Copied to clipboard");
+    emit alert(tr("Copied to clipboard"));
 }
