@@ -63,7 +63,7 @@ void DownloadManager::parseVideoPage() {
         index++;
     }
     if (videoUrl == "") {
-        emit statusChanged("Failed");
+        emit statusChanged(tr("Failed"));
     }
     else {
         emit gotVideoUrl(videoUrl);
@@ -118,7 +118,7 @@ void DownloadManager::performDownload(const QByteArray &videoUrl) {
     }
 
     downloadReply = nam->get(request);
-    emit statusChanged("Downloading");
+    emit statusChanged(tr("Downloading"));
     downloadTime.start();
     connect(downloadReply, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(updateProgress(qint64,qint64)));
     connect(downloadReply, SIGNAL(finished()), this, SLOT(downloadFinished()));
@@ -153,10 +153,10 @@ void DownloadManager::downloadFinished() {
         QString status;
         if (downloadReply->error()) {
             if (downloadReply->error() == QNetworkReply::OperationCanceledError) {
-                status = "Paused";
+                status = tr("Paused");
             }
             else {
-                status = "Failed";
+                status = tr("Failed");
             }
             emit statusChanged(status);
         }
