@@ -1,6 +1,7 @@
 #include "qmlapplicationviewer.h"
 #include "controller.h"
 #include "youtube.h"
+#include "sharing.h"
 #include "downloadmanager.h"
 #include "folderlistmodel.h"
 #include <QtGui/QApplication>
@@ -20,21 +21,25 @@ int main(int argc, char *argv[])
 
     QDeclarativeContext *context = viewer.rootContext();
     Controller ct;
+    ct.setLanguage();
     ct.setView(&viewer);
     YouTube yt;
+    Sharing sh;
     DownloadManager dm;
     QNetworkAccessManager *manager = new QNetworkAccessManager();
     yt.setNetworkAccessManager(manager);
     dm.setNetworkAccessManager(manager);
+    sh.setNetworkAccessManager(manager);
     context->setContextProperty("Controller", &ct);
     context->setContextProperty("DownloadManager", &dm);
     context->setContextProperty("YouTube", &yt);
+    context->setContextProperty("Sharing", &sh);
 
     qmlRegisterType<QDeclarativeFolderListModel>("Models",1,0,"FolderListModel");
 
 #ifdef Q_WS_MAEMO_5
-//    viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
-//    viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
+    //    viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
+    //    viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
     viewer.engine()->setOfflineStoragePath("/home/user/.config/cutetube");
     QDir path;
     path.setPath("/home/user/.config/cutetube");
@@ -45,8 +50,9 @@ int main(int argc, char *argv[])
     if (!path.exists()) {
         path.mkpath("/home/user/MyDocs/.cutetube");
     }
-//    viewer.setViewport(new QGLWidget());
+    //    viewer.setViewport(new QGLWidget());
 #endif
+
     viewer.setMainQmlFile(QLatin1String("qml/qmltube/main.qml"));
     viewer.showFullScreen();
 
